@@ -24,6 +24,7 @@ from calculate.core.server.api_types import ReturnedMessage
 from calculate.core.server.api_types import ChoiceValue, Table, Option, Field, \
                                            GroupField, ViewInfo, ViewParams
 from calculate.lib.datavars import VariableError,DataVarsError
+from calculate.install.cl_install import InstallError
 
 #from cl_install import Install,DataVarsInstall
 import cl_install
@@ -107,7 +108,7 @@ class catchExcept:
                     default = 'color:red;',
                     element = "error"))
             view.groups.append(group)
-            if not isinstance(VariableError,DataVarsError,InstallError):
+            if not type(e) in (InstallError,DataVarsError,VariableError):
                 for i in apply(traceback.format_exception, sys.exc_info()):
                     print i,
 
