@@ -337,7 +337,7 @@ class VariableHrMemorySize(ReadonlyVariable):
         return "0"
 
     def humanReadable(self):
-        return map(humanreadableSize,self.Get())
+        return humanreadableSize(self.Get())
 
 class VariableClAutopartitionSwapSize(Variable):
     """
